/**
 * The sides allowed by Packwiz.
 */
export enum Side {
  /**
   * Download a file on both clients and servers.
   */
  "Both" = "both",
  /**
   * Download a file only on clients.
   */
  "Client" = "client",
  /**
   * Download a file only on servers.
   */
  "Server" = "server",
}

/**
 * Checks if the provided side is allowed by Packwiz.
 * @param side - The side to check.
 * @returns The Side enum value if valid, otherwise throws an error.
 */
export function isValidSide(side: string | undefined): Side {
  if (side == undefined) {
    return Side.Both;
  }

  if (Object.values(Side).includes(side.toLowerCase() as Side)) {
    return side.toLowerCase() as Side;
  } else {
    throw new Error("Invalid side!");
  }
}
